@@ -23,6 +23,7 @@
 from typing import Dict
 from typing import List
 from typing import Tuple
+from typing import NamedTuple
 from typing import Iterable
 from typing import Any
 import sys
@@ -916,147 +917,62 @@ def convert_digits_to_ascii(text: str) -> str:
     '''
     return text.translate(DIGIT_TRANS_TABLE)
 
+class TransliterationParts(NamedTuple):
+    '''
+    A named tuple containing the parts of a transliteration
+
+    committed: str        The part of the transliteration which cannot be
+                          changed anymore by adding more input, could be
+                          committed already if desired.
+    committed_index: int  The index up to which the msymbol_list input
+                          was “used up” to create the “committed” text.
+    preedit:              The transliteration of the remaining input,
+                          may still change by adding more input.
+    cursor_pos: int       The cursor position in the preedit.
+                          Counted in codepoints, not glyphs (For example
+                          '☺\uFE0F' usually renders as one glyph (☺️) but
+                          has two codepoints).
+                          Usually this is at the end of the preedit but
+                          not always! An input method may move the cursor
+                          within the preedit!
+                          (I think only ja-anthy.mim actually moves the
+                          cursor within the preedit sometimes when moving
+                          or resizing the henkan region).
+    status: str           May change for some input methods to
+                          indicate a state.
+                          For example in case of ja-anthy.mim,
+                          this is 'aあ' before Henkan and changes
+                          to '漢' in Henkan mode.
+    candidates: List[str] May contain a list of candidates if the
+                          input method can produce multiple candidates.
+    candidate_index: int  Index of the selected candidate.
+                          0 if no candidate is selected.
+    candidate_from: int   Start of the current candidate in the preedit.
+    candidate_to: int     End of the  current candidate in the preedit.
+                          If candidate_index == 0, i.e.
+                          no candidate is selected, the current candidate
+                          in the preedit is the first candidate.
+    candidate_show: int   0: candidates should be hidden
+                          1: candidates should be shown
+    '''
+    committed: str = ''
+    committed_index: int = 0
+    preedit: str = ''
+    cursor_pos: int = 0
+    status: str = ''
+    candidates: List[str] = []
+    candidate_index: int = 0
+    candidate_from: int = 0
+    candidate_to: int = 0
+    candidate_show: int = 0
+
 class Transliterator:
-    # pylint: disable=line-too-long
     '''A class for transliterators using libm17n
 
     If initializing the transliterator fails, for example because a
     non-existing input method was given as the argument, a ValueError
-    is raised:
-
-    Examples:
-
-    Russian transliteration:
-
-    >>> trans = Transliterator('ru-translit')
-    >>> trans.transliterate(list('y'))
-    'ы'
-    >>> trans.transliterate(list('yo'))
-    'ё'
-    >>> trans.transliterate(list('yo y'))
-    'ё ы'
-
-    Marathi transliteration:
-
-    >>> trans = Transliterator('mr-itrans')
-    >>> trans.transliterate(list('praviN'))
-    'प्रविण्'
-    >>> trans.transliterate(list('namaste'))
-    'नमस्ते'
-
-    Hindi transliteration:
-
-    >>> trans = Transliterator('hi-itrans')
-    >>> trans.transliterate(list('namaste'))
-    'नमस्ते'
-
-    >>> trans.transliterate_parts(list('n'))
-    ('', 0, 'न्', 2, 'क', [])
-    >>> trans.transliterate_parts(list('n '))
-    ('न ', 2, '', 0, 'क', [])
-    >>> trans.transliterate_parts(list('na'))
-    ('', 0, 'न', 1, 'क', [])
-    >>> trans.transliterate_parts(list('nam'))
-    ('न', 2, 'म्', 2, 'क', [])
-    >>> trans.transliterate_parts(list('nama'))
-    ('न', 2, 'म', 1, 'क', [])
-    >>> trans.transliterate_parts(list('namas'))
-    ('नम', 4, 'स्', 2, 'क', [])
-    >>> trans.transliterate_parts(list('namast'))
-    ('नम', 4, 'स्त्', 4, 'क', [])
-    >>> trans.transliterate_parts(list('namaste'))
-    ('नम', 4, 'स्ते', 4, 'क', [])
-    >>> trans.transliterate_parts(list('namaste '))
-    ('नमस्ते ', 8, '', 0, 'क', [])
-
-    >>> trans.transliterate(list('. '))
-    '। '
-
-    Hindi-Inscript2 uses the AltGr key a lot, 'G-4' is
-    the MSymbol name for AltGr-4 and it transliterates
-    to something different than just '4':
-
-    >>> trans = Transliterator('hi-inscript2')
-    >>> trans.transliterate(['4', 'G-4'])
-    '४₹'
-
-    >>> trans = Transliterator('hi-inscript2')
-    >>> trans.transliterate(['G-p'])
-    'ज़'
-
-    AltGr-3 ('G-3') is not used though in Hindi-Inscript2.
-    Therefore, 'G-3' transliterates just as 'G-3':
-
-    >>> trans = Transliterator('hi-inscript2')
-    >>> trans.transliterate(['3', 'G-3'])
-    '३G-3'
-
-    In mr-inscript2, 'G-1' transliterates to U+200D ZERO WIDTH JOINER
-    ('\xe2\x80\x8d' in UTF-8 encoding):
-
-    >>> trans = Transliterator('mr-inscript2')
-    >>> trans.transliterate(['j', 'd', 'G-1', '/']).encode('utf-8')
-    b'\xe0\xa4\xb0\xe0\xa5\x8d\xe2\x80\x8d\xe0\xa4\xaf'
-
-    >>> trans = Transliterator('t-latn-post')
-    >>> trans.transliterate(list('gru"n'))
-    'grün'
-
-    >>> trans = Transliterator('NoIME')
-    >>> trans.transliterate(['a', 'b', 'c', 'C-c', 'G-4', 'C-α', 'G-α'])
-    'abcC-cG-4C-αG-α'
-
-    >>> trans = Transliterator('ko-romaja')
-    >>> trans.transliterate(list('annyeonghaseyo'))
-    '안녕하세요'
-
-    >>> trans = Transliterator('si-wijesekara')
-    >>> trans.transliterate(list('vksIal kjSka '))
-    'ඩනිෂ්ක නවීන් '
-
-    >>> trans = Transliterator('t-latn-post')
-    >>> trans.transliterate_parts(list('u'))
-    ('', 0, 'u', 1, 'Latin-post', [])
-    >>> trans.transliterate_parts(list('u"'))
-    ('', 0, 'ü', 1, 'Latin-post', [])
-    >>> trans.transliterate_parts(list('u""'))
-    ('u"', 3, '', 0, 'Latin-post', [])
-    >>> trans.transliterate_parts(list('u"u'))
-    ('ü', 2, 'u', 1, 'Latin-post', [])
-    >>> trans.transliterate_parts(list('üu"u'))
-    ('üü', 3, 'u', 1, 'Latin-post', [])
-
-    >>> trans = Transliterator('t-rfc1345')
-    >>> trans.transliterate_parts(list('&'))
-    ('', 0, '&', 1, 'RFC1345', [])
-    >>> trans.transliterate_parts(list('&C'))
-    ('', 0, '&C', 2, 'RFC1345', [])
-    >>> trans.transliterate_parts(list('&Co'))
-    ('©', 3, '', 0, 'RFC1345', [])
-    >>> trans.transliterate_parts(list('&f'))
-    ('', 0, '&f', 2, 'RFC1345', [])
-    >>> trans.transliterate_parts(list('&ff'))
-    ('', 0, 'ﬀ', 1, 'RFC1345', [])
-    >>> trans.transliterate_parts(list('&ffi'))
-    ('ﬃ', 4, '', 0, 'RFC1345', [])
-
-    >>> trans = Transliterator('t-lsymbol')
-    >>> trans.transliterate_parts(list('/:)'))
-    ('', 0, '☺️', 2, 'lsymbol', ['☺️', '😃', '😅', '😆', '😉', '😇', '😂', '😏', '😛', '😜', '😝', '😋', '😉', '💏', '💋', '😍', '😘', '😚', '😽', '😻'])
-    >>> trans.transliterate_parts(list('a'))
-    ('a', 1, '', 0, 'lsymbol', [])
-    >>> trans.transliterate_parts(list('a/'))
-    ('a', 1, '/', 1, 'lsymbol', [])
-    >>> trans.transliterate_parts(list('a/:'))
-    ('a', 1, '/:', 2, 'lsymbol', [])
-    >>> trans.transliterate_parts(list('a/:('))
-    ('a', 1, '😢', 1, 'lsymbol', ['😢', '😩', '😡', '😭', '😪', '🙈', '🙊', '🙉'])
-    >>> trans.transliterate_parts(list('a/:(b'))
-    ('a😢b', 5, '', 0, 'lsymbol', [])
-
-    For a test transliterating parts using 'ja-anthy' see 'tests/test_m17n_translit.py'.
+    is raised.
     '''
-    # pylint: enable=line-too-long
     def __init__(self, ime: str) -> None:
         '''Initialize the input method to use for the transliteration
 
@@ -1092,7 +1008,8 @@ class Transliterator:
     def transliterate_parts(
             self,
             msymbol_list: Iterable[str],
-            ascii_digits: bool = False) -> Tuple[str, int, str, int, str, List[str]]:
+            ascii_digits: bool = False) -> TransliterationParts:
+        # pylint: disable=line-too-long
         '''Transliterate a list of Msymbol names
 
         :param msymbol_list: A list of strings which are interpreted
@@ -1102,35 +1019,416 @@ class Transliterator:
                              Msymbols is just joined to a single string.
         :param ascii_digits: If true, convert language specific digits
                              to ASCII digits
-        :return: The transliteration in several parts:
+        :return: The transliteration in several parts
 
-        (committed, committed_index, preedit, cursor_pos, status, candidates)
+        Examples:
 
-        committed: str        The part of the transliteration which cannot be
-                              changed anymore by adding more input, could be
-                              committed already if desired.
-        committed_index: int  The index up to which the msymbol_list input
-                              was “used up” to create the “committed” text.
-        preedit:              The transliteration of the remaining input,
-                              may still change by adding more input.
-        cursor_pos: int       The cursor position in the preedit.
-                              Counted in codepoints, not glyphs.
-                              Usually this is at the end of the preedit
-                              but an input method may move the cursor
-                              within the preedit!
-                              (I think only ja-anthy.mim actually uses this)
-        status: str           May change for some input methods to
-                              indicate a state.
-                              For example in case of ja-anthy.mim,
-                              this is 'aあ' before Henkan and changes
-                              to '漢' in Henkan mode.
-        candidates: List[str] May contain a list of candidates if the
-                              input method can produce multiple candidates.
+        >>> trans = Transliterator('hi-itrans')
+        >>> parts = trans.transliterate_parts(list('n'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        'न्'
+        >>> parts.cursor_pos
+        2
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('n '))
+        >>> parts.committed
+        'न '
+        >>> parts.committed_index
+        2
+        >>> parts.preedit
+        ''
+        >>> parts.cursor_pos
+        0
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts =trans.transliterate_parts(list('na'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        'न'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('nam'))
+        >>> parts.committed
+        'न'
+        >>> parts.committed_index
+        2
+        >>> parts.preedit
+        'म्'
+        >>> parts.cursor_pos
+        2
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('nama'))
+        >>> parts.committed
+        'न'
+        >>> parts.committed_index
+        2
+        >>> parts.preedit
+        'म'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('namas'))
+        >>> parts.committed
+        'नम'
+        >>> parts.committed_index
+        4
+        >>> parts.preedit
+        'स्'
+        >>> parts.cursor_pos
+        2
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('namast'))
+        >>> parts.committed
+        'नम'
+        >>> parts.committed_index
+        4
+        >>> parts.preedit
+        'स्त्'
+        >>> parts.cursor_pos
+        4
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('namaste'))
+        >>> parts.committed
+        'नम'
+        >>> parts.committed_index
+        4
+        >>> parts.preedit
+        'स्ते'
+        >>> parts.cursor_pos
+        4
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('namaste '))
+        >>> parts.committed
+        'नमस्ते '
+        >>> parts.committed_index
+        8
+        >>> parts.preedit
+        ''
+        >>> parts.cursor_pos
+        0
+        >>> parts.status
+        'क'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+
+        >>> trans = Transliterator('t-latn-post')
+        >>> parts = trans.transliterate_parts(list('u'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        'u'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'Latin-post'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('u"'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        'ü'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'Latin-post'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('u""'))
+        >>> parts.committed
+        'u"'
+        >>> parts.committed_index
+        3
+        >>> parts.preedit
+        ''
+        >>> parts.cursor_pos
+        0
+        >>> parts.status
+        'Latin-post'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('u"u'))
+        >>> parts.committed
+        'ü'
+        >>> parts.committed_index
+        2
+        >>> parts.preedit
+        'u'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'Latin-post'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('üu"u'))
+        >>> parts.committed
+        'üü'
+        >>> parts.committed_index
+        3
+        >>> parts.preedit
+        'u'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'Latin-post'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+
+        >>> trans = Transliterator('t-rfc1345')
+        >>> parts = trans.transliterate_parts(list('&'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        '&'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'RFC1345'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('&C'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        '&C'
+        >>> parts.cursor_pos
+        2
+        >>> parts.status
+        'RFC1345'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('&Co'))
+        >>> parts.committed
+        '©'
+        >>> parts.committed_index
+        3
+        >>> parts.preedit
+        ''
+        >>> parts.cursor_pos
+        0
+        >>> parts.status
+        'RFC1345'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('&f'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        '&f'
+        >>> parts.cursor_pos
+        2
+        >>> parts.status
+        'RFC1345'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('&ff'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        'ﬀ'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'RFC1345'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('&ffi'))
+        >>> parts.committed
+        'ﬃ'
+        >>> parts.committed_index
+        4
+        >>> parts.preedit
+        ''
+        >>> parts.cursor_pos
+        0
+        >>> parts.status
+        'RFC1345'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+
+        >>> trans = Transliterator('t-lsymbol')
+        >>> parts = trans.transliterate_parts(list('/:)'))
+        >>> parts.committed
+        ''
+        >>> parts.committed_index
+        0
+        >>> parts.preedit
+        '☺️'
+        >>> parts.cursor_pos
+        2
+        >>> parts.status
+        'lsymbol'
+        >>> parts.candidates
+        ['☺️', '😃', '😅', '😆', '😉', '😇', '😂', '😏', '😛', '😜', '😝', '😋', '😉', '💏', '💋', '😍', '😘', '😚', '😽', '😻']
+        >>> parts.candidate_show
+        1
+        >>> parts = trans.transliterate_parts(list('a'))
+        >>> parts.committed
+        'a'
+        >>> parts.committed_index
+        1
+        >>> parts.preedit
+        ''
+        >>> parts.cursor_pos
+        0
+        >>> parts.status
+        'lsymbol'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+        >>> parts = trans.transliterate_parts(list('a/'))
+        >>> parts.committed
+        'a'
+        >>> parts.committed_index
+        1
+        >>> parts.preedit
+        '/'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'lsymbol'
+        >>> parts.candidates
+        ['/']
+        >>> parts.candidate_show
+        1
+        >>> parts = trans.transliterate_parts(list('a/:'))
+        >>> parts.committed
+        'a'
+        >>> parts.committed_index
+        1
+        >>> parts.preedit
+        '/:'
+        >>> parts.cursor_pos
+        2
+        >>> parts.status
+        'lsymbol'
+        >>> parts.candidates
+        ['/:']
+        >>> parts.candidate_show
+        1
+        >>> parts = trans.transliterate_parts(list('a/:('))
+        >>> parts.committed
+        'a'
+        >>> parts.committed_index
+        1
+        >>> parts.preedit
+        '😢'
+        >>> parts.cursor_pos
+        1
+        >>> parts.status
+        'lsymbol'
+        >>> parts.candidates
+        ['😢', '😩', '😡', '😭', '😪', '🙈', '🙊', '🙉']
+        >>> parts.candidate_show
+        1
+        >>> parts = trans.transliterate_parts(list('a/:(b'))
+        >>> parts.committed
+        'a😢b'
+        >>> parts.committed_index
+        5
+        >>> parts.preedit
+        ''
+        >>> parts.cursor_pos
+        0
+        >>> parts.status
+        'lsymbol'
+        >>> parts.candidates
+        []
+        >>> parts.candidate_show
+        0
+
+        For a test transliterating parts using 'ja-anthy' see 'tests/test_m17n_translit.py'.
         '''
+        # pylint: enable=line-too-long
         if not isinstance(msymbol_list, list):
             raise ValueError('Argument of transliterate() must be a list.')
         if self._dummy:
-            return (''.join(msymbol_list), 0, '', 0, '', [])
+            return TransliterationParts(committed=''.join(msymbol_list),
+                                       committed_index=len(msymbol_list))
         libm17n__minput_reset_ic(self._ic) # type: ignore
         committed = ''
         committed_index = 0
@@ -1202,6 +1500,10 @@ class Transliterator:
             plist = libm17n__mplist_next(plist) # type: ignore
         cursor_pos = self._ic.contents.cursor_pos
         status = mtext_to_string(self._ic.contents.status)
+        candidate_index = self._ic.contents.candidate_index
+        candidate_from = self._ic.contents.candidate_from
+        candidate_to = self._ic.contents.candidate_to
+        candidate_show = self._ic.contents.candidate_show
         # From the m17n-lib documentation:
         #
         # The minput_reset_ic () function resets input context $IC by
@@ -1228,19 +1530,109 @@ class Transliterator:
             self._ic, _symbol, ctypes.c_void_p(None))
         if committed and not preedit:
             committed_index = len(msymbol_list)
+        # Some Chinese input methods and some Vietnamese input methods
+        # for Chinese characters sometimes have “candidates == []” but
+        # at the same time “candidate_show == 1”:
+        #
+        # For example zh-cangjie.mim contains:
+        #
+        #  (map
+        #   ("a" ("日曰"))
+        #   ("aa" ("昌昍"))
+        #   ("aaa" ?晶)
+        #   ("aaaa" ("𣊫𣊭"))
+        #   [...]
+        #
+        # The ?晶 produces “candidates == []”, ("晶") would
+        # produce “candidates == ['晶']”
+        #
+        # In that case typing `a` and `aa` produces candidates but
+        # `aaa` does not and `aaaa` produces candidates again.  That
+        # is bad because Typing Booster behaves differently when there
+        # are candidates and when there are not.  So it would behave
+        # inconsistently while typing `aaaa` if `aaa` suddenly has no
+        # candidates and suddenly shows a “normal” typing booster
+        # completion lookup table.
+        #
+        # Other input methods which have the same problem are
+        # zh-tonepy, vi-nomtelex, vi-nomvni, ...
+        #
+        # So copy the preedit into candidates if they are empty and
+        # candidate_show is one for more consistent behaviour (in my
+        # opinion):
+        if preedit and not candidates and candidate_show:
+            candidates = [preedit]
+        if self._language == 'ja' and self._name == 'anthy':
+            # ja-anthy produces a lot of useless geta marks '〓'.  It
+            # also produces sometimes useless empty candidates and
+            # sometimes (when transliterating `1 `) even preedit='',
+            # cursor_pos=1.
+            #
+            # All these problems seem to be encoding problems caused
+            # by mimx-anthy.c in m17n-lib using EUC-JP encoding
+            # instead of UTF-8.  They all go away go away after fixing
+            # mimx-anthy.c to use UTF-8 by patching it like this:
+            #
+            # --- a/example/mimx-anthy.c
+            # +++ b/example/mimx-anthy.c
+            # @@ -129,15 +129,16 @@ new_context (MInputContext *ic)
+            #  {
+            #    AnthyContext *context;
+            #    anthy_context_t ac;
+            # -  MSymbol euc_jp = msymbol ("euc-jp");
+            # +  MSymbol utf_8 = msymbol ("utf-8");
+            #    /* Rebound to an actual buffer just before being used.  */
+            # -  MConverter *converter = mconv_buffer_converter (euc_jp, NULL, 0);
+            # +  MConverter *converter = mconv_buffer_converter (utf_8, NULL, 0);
+            #
+            #    if (! converter)
+            #      return NULL;
+            #    ac = anthy_create_context ();
+            #    if (! ac)
+            #      return NULL;
+            # +  anthy_context_set_encoding(ac, ANTHY_UTF8_ENCODING);
+            #    context = calloc (1, sizeof (AnthyContext));
+            #    context->ic = ic;
+            #    context->ac = ac;
+            #
+            # It is not necessary to use anthy-unicode (although this is
+            # probably better), I tested that this encoding problem here
+            # can be fixed by just patching mimx-anthy.c. Tested with
+            # anthy-9100h-56.fc41.x86_64
+            # anthy-unicode-1.0.0.20240502-8.fc41.x86_64
+            #
+            # For systems where mimx-anthy.c has not been fixed yet
+            # in m17n-lib, apply a runtime fix here:
+            if preedit != '下駄':
+                candidates = [
+                    candidate
+                    for candidate in candidates
+                    if candidate and '〓' not in candidate]
+            if not preedit and candidates:
+                preedit = candidates[0]
+                cursor_pos = len(preedit)
         if not ascii_digits:
-            return (committed,
-                    committed_index,
-                    preedit,
-                    cursor_pos,
-                    status,
-                    candidates)
-        return (convert_digits_to_ascii(committed),
-                committed_index,
-                convert_digits_to_ascii(preedit),
-                cursor_pos,
-                status,
-                candidates)
+            return TransliterationParts(committed=committed,
+                                       committed_index=committed_index,
+                                       preedit=preedit,
+                                       cursor_pos=cursor_pos,
+                                       status=status,
+                                       candidates=candidates,
+                                       candidate_index=candidate_index,
+                                       candidate_from=candidate_from,
+                                       candidate_to=candidate_to,
+                                       candidate_show=candidate_show)
+        return TransliterationParts(
+            committed=convert_digits_to_ascii(committed),
+            committed_index=committed_index,
+            preedit=convert_digits_to_ascii(preedit),
+            cursor_pos=cursor_pos,
+            status=status,
+            candidates=candidates,
+            candidate_index=candidate_index,
+            candidate_from=candidate_from,
+            candidate_to=candidate_to,
+            candidate_show=candidate_show)
 
     def transliterate(self, msymbol_list: Iterable[str], ascii_digits: bool = False) -> str:
         '''Transliterate a list of Msymbol names
@@ -1253,15 +1645,80 @@ class Transliterator:
         :param ascii_digits: If true, convert language specific digits
                              to ASCII digits
         :return: The transliteration in one string
+
+        Examples:
+
+        Russian transliteration:
+
+        >>> trans = Transliterator('ru-translit')
+        >>> trans.transliterate(list('y'))
+        'ы'
+        >>> trans.transliterate(list('yo'))
+        'ё'
+        >>> trans.transliterate(list('yo y'))
+        'ё ы'
+
+        Marathi transliteration:
+
+        >>> trans = Transliterator('mr-itrans')
+        >>> trans.transliterate(list('praviN'))
+        'प्रविण्'
+        >>> trans.transliterate(list('namaste'))
+        'नमस्ते'
+
+        Hindi transliteration:
+
+        >>> trans = Transliterator('hi-itrans')
+        >>> trans.transliterate(list('namaste'))
+        'नमस्ते'
+        >>> trans.transliterate(list('. '))
+        '। '
+
+        Hindi-Inscript2 uses the AltGr key a lot, 'G-4' is
+        the MSymbol name for AltGr-4 and it transliterates
+        to something different than just '4':
+
+        >>> trans = Transliterator('hi-inscript2')
+        >>> trans.transliterate(['4', 'G-4'])
+        '४₹'
+
+        >>> trans = Transliterator('hi-inscript2')
+        >>> trans.transliterate(['G-p'])
+        'ज़'
+
+        AltGr-3 ('G-3') is not used though in Hindi-Inscript2.
+        Therefore, 'G-3' transliterates just as 'G-3':
+
+        >>> trans = Transliterator('hi-inscript2')
+        >>> trans.transliterate(['3', 'G-3'])
+        '३G-3'
+
+        In mr-inscript2, 'G-1' transliterates to U+200D ZERO WIDTH JOINER
+        ('\xe2\x80\x8d' in UTF-8 encoding):
+
+        >>> trans = Transliterator('mr-inscript2')
+        >>> trans.transliterate(['j', 'd', 'G-1', '/']).encode('utf-8')
+        b'\xe0\xa4\xb0\xe0\xa5\x8d\xe2\x80\x8d\xe0\xa4\xaf'
+
+        >>> trans = Transliterator('t-latn-post')
+        >>> trans.transliterate(list('gru"n'))
+        'grün'
+
+        >>> trans = Transliterator('NoIME')
+        >>> trans.transliterate(['a', 'b', 'c', 'C-c', 'G-4', 'C-α', 'G-α'])
+        'abcC-cG-4C-αG-α'
+
+        >>> trans = Transliterator('ko-romaja')
+        >>> trans.transliterate(list('annyeonghaseyo'))
+        '안녕하세요'
+
+        >>> trans = Transliterator('si-wijesekara')
+        >>> trans.transliterate(list('vksIal kjSka '))
+        'ඩනිෂ්ක නවීන් '
         '''
-        (committed,
-         _committed_index,
-         preedit,
-         _cursor_pos,
-         _status,
-         _candidates) = self.transliterate_parts(
+        transliteration_parts = self.transliterate_parts(
             msymbol_list, ascii_digits)
-        return committed + preedit
+        return transliteration_parts.committed + transliteration_parts.preedit
 
     def get_variables(self) -> List[Tuple[str, str, str]]:
         # pylint: disable=line-too-long
