@@ -54,6 +54,8 @@ from mock_engine import MockProperty
 from mock_engine import MockPropList
 # pylint: enable=import-error
 
+import testutils # pylint: disable=import-error
+
 # pylint: disable=wrong-import-order
 sys.path.insert(0, "../engine")
 # pylint: disable=import-error
@@ -90,6 +92,7 @@ class ItbM17nEmuTestCase(unittest.TestCase):
 
     orig_disable_in_terminals = False
     orig_ascii_digits = False
+    orig_word_prediction_mode = True
     orig_emoji_prediction_mode = False
     orig_off_the_record_mode = False
     orig_record_mode = 0
@@ -111,7 +114,7 @@ class ItbM17nEmuTestCase(unittest.TestCase):
     orig_avoid_forward_key_event = False
     orig_keybindings: Dict[str, List[str]] = {}
     orig_use_ibus_keymap = False
-    orig_ibus_keykmap = 'in'
+    orig_ibus_keymap = 'in'
 
     def setUp(self) -> None:
         # Patch the IBus stuff with the mock classes:
@@ -164,6 +167,8 @@ class ItbM17nEmuTestCase(unittest.TestCase):
             self.engine.get_disable_in_terminals())
         self.orig_ascii_digits = (
             self.engine.get_ascii_digits())
+        self.orig_word_prediction_mode = (
+            self.engine.get_word_prediction_mode())
         self.orig_emoji_prediction_mode = (
             self.engine.get_emoji_prediction_mode())
         self.orig_off_the_record_mode = (
@@ -218,6 +223,9 @@ class ItbM17nEmuTestCase(unittest.TestCase):
         self.engine.set_ascii_digits(
             self.orig_ascii_digits,
             update_gsettings=False)
+        self.engine.set_word_prediction_mode(
+            self.orig_word_prediction_mode,
+            update_gsettings=False)
         self.engine.set_emoji_prediction_mode(
             self.orig_emoji_prediction_mode,
             update_gsettings=False)
@@ -341,6 +349,13 @@ class ItbM17nEmuTestCase(unittest.TestCase):
         self.init_engine()
         self.assertEqual(False, True)
 
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
+        'Skipping because no en_US hunspell dictionary could be found.')
+    @unittest.skipUnless(
+        testutils.get_hunspell_dictionary_length('en_US') >= 10000,
+        'Skipping because en_US dictionary is suspiciously small, '
+        'see: https://bugzilla.redhat.com/show_bug.cgi?id=2218460')
     def test_typing_booster_normal(self) -> None:
         self.init_engine(engine_name='typing-booster')
         if self.engine is None:
@@ -363,11 +378,13 @@ class ItbM17nEmuTestCase(unittest.TestCase):
         self.assertEqual(self.engine._engine_name, 'tb:t:latn-post')
         self.assertEqual(self.engine._dictionary_names, ['None'])
         self.assertEqual(self.engine._current_imes, ['t-latn-post'])
-        self.assertEqual(self.engine._tab_enable, True)
+        self.assertEqual(self.engine._tab_enable, False) # normal default
+        self.assertEqual(self.engine._word_predictions, False)
+        self.assertEqual(self.engine._emoji_predictions, False)
         self.assertEqual(self.engine._off_the_record, True)
         self.assertEqual(self.engine._preedit_underline, 0)
         self.assertEqual(self.engine._keybindings['toggle_input_mode_on_off'], [])
-        self.assertEqual(self.engine._keybindings['enable_lookup'], [])
+        self.assertEqual(self.engine._keybindings['enable_lookup'], ['Tab', 'ISO_Left_Tab']) # normal default
         self.assertEqual(self.engine._keybindings['commit_and_forward_key'], ['Left'])
         self.engine.do_process_key_event(IBus.KEY_a, 0, 0)
         self.assertEqual(self.engine.mock_preedit_text, 'a')
